@@ -20,10 +20,9 @@
 #ifndef _tdsver_h_
 #define _tdsver_h_
 
-#define VERSION_NO "freetds v0.53"
+static char rcsid_tdsver_h[] = "$Id: tdsver.h.in,v 1.4 2002/11/21 16:53:43 freddy77 Exp $";
+static void *no_unused_tdsver_h_warn[] = { rcsid_tdsver_h, no_unused_tdsver_h_warn };
 
-static char  rcsid_tdsver_h [ ] =
-         "$Header: /cvsroot/freetds/freetds/include/tdsver.h.in,v 1.1.1.1 2001/10/12 23:28:55 brianb Exp $";
-static void *no_unused_tdsver_h_warn[]={rcsid_tdsver_h, no_unused_tdsver_h_warn};
+#define TDS_VERSION_NO "freetds v0.61"
 
 #endif
