@@ -16,26 +16,38 @@
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
  */
-
+#if HAVE_CONFIG_H
 #include <config.h>
+#endif /* HAVE_CONFIG_H */
+
+#if HAVE_STDLIB_H
+#include <stdlib.h>
+#endif /* HAVE_STDLIB_H */
+
 #include "tds.h"
-#include "tdsutil.h"
-#include <unistd.h>
+#include "tdssrv.h"
 
-static char  software_version[]   = "$Id: query.c,v 1.2 2001/10/24 23:19:44 brianb Exp $";
-static void *no_unused_var_warn[] = {software_version,
-                                     no_unused_var_warn};
+static char software_version[] = "$Id: query.c,v 1.11 2003/01/26 10:27:36 freddy77 Exp $";
+static void *no_unused_var_warn[] = { software_version, no_unused_var_warn };
 
-
-
-char *tds_get_query(TDSSOCKET *tds) 
+char *
+tds_get_query(TDSSOCKET * tds)
 {
-static unsigned char query[BUFSIZ];
+static unsigned char *query;
+static size_t query_buflen = 0;
 int len;
 
-	tds_get_byte(tds); /* 33 */
-	len = tds_get_smallint(tds); /* query size +1 */
-	tds_get_n(tds,NULL,3);
+	if (query_buflen == 0) {
+		query_buflen = 1024;
+		query = (unsigned char*) malloc(query_buflen);
+	}
+	tds_get_byte(tds);	/* 33 */
+	len = tds_get_smallint(tds);	/* query size +1 */
+	tds_get_n(tds, NULL, 3);
+	if (len > query_buflen) {
+		query_buflen = len;
+		query = (unsigned char*) realloc(query, query_buflen);
+	}
 	tds_get_n(tds, query, len - 1);
-	return query;
+	return (char *) query;
 }
